@@ -13,6 +13,7 @@ import re
 import time
 import subprocess
 import socket
+import netaddr
 import unittest
 import ctypes
 
@@ -23,9 +24,8 @@ except ImportError:
 
 import gi
 
-gi.require_version('NetworkManager', '1.0')
-gi.require_version('NMClient', '1.0')
-from gi.repository import NetworkManager, NMClient, GLib
+gi.require_version('NM', '1.0')
+from gi.repository import NM, GLib, Gio
 
 sys.path.append(os.path.dirname(__file__))
 import network_test_base
@@ -117,7 +117,7 @@ class NetworkManagerTest(network_test_base.NetworkTestBase):
             if wait_iface:
                 self.poll_text(log, 'manager: (%s): new' % wait_iface, timeout=100)
 
-        self.nmclient = NMClient.Client.new()
+        self.nmclient = NM.Client.new()
         self.assertTrue(self.nmclient.networking_get_enabled())
 
         # FIXME: This certainly ought to be true, but isn't
@@ -126,19 +126,19 @@ class NetworkManagerTest(network_test_base.NetworkTestBase):
         # determine device objects
         for d in self.nmclient.get_devices():
             if d.props.interface == self.dev_w_ap:
-                self.assertEqual(d.get_device_type(), NetworkManager.DeviceType.WIFI)
+                self.assertEqual(d.get_device_type(), NM.DeviceType.WIFI)
                 self.assertEqual(d.get_driver(), 'mac80211_hwsim')
                 self.assertEqual(d.get_hw_address(), self.mac_w_ap)
                 self.nmdev_w_ap = d
             elif d.props.interface == self.dev_w_client:
-                self.assertEqual(d.get_device_type(), NetworkManager.DeviceType.WIFI)
+                self.assertEqual(d.get_device_type(), NM.DeviceType.WIFI)
                 self.assertEqual(d.get_driver(), 'mac80211_hwsim')
                 # NM ≥ 1.4 randomizes MAC addresses by default, so we can't
                 # test for equality, just make sure it's not our AP
                 self.assertNotEqual(d.get_hw_address(), self.mac_w_ap)
                 self.nmdev_w = d
             elif d.props.interface == self.dev_e_client:
-                self.assertEqual(d.get_device_type(), NetworkManager.DeviceType.ETHERNET)
+                self.assertEqual(d.get_device_type(), NM.DeviceType.VETH)
                 self.assertEqual(d.get_driver(), 'veth')
                 self.assertEqual(d.get_hw_address(), self.mac_e_client)
                 self.nmdev_e = d
@@ -240,43 +240,67 @@ class NetworkManagerTest(network_test_base.NetworkTestBase):
         secret should be None for open networks, and a string with the password
         for WEP/WPA.
 
-        ip6_privacy is a NetworkManager.SettingIP6ConfigPrivacy flag.
+        ip6_privacy is a NM.SettingIP6ConfigPrivacy flag.
 
         Return (NMConnection, NMActiveConnection) objects.
         '''
 
-        ip4_method = NetworkManager.SETTING_IP4_CONFIG_METHOD_DISABLED
-        ip6_method = NetworkManager.SETTING_IP6_CONFIG_METHOD_IGNORE
+        ip4_method = NM.SETTING_IP4_CONFIG_METHOD_DISABLED
+        ip6_method = NM.SETTING_IP6_CONFIG_METHOD_IGNORE
         if ipv6_mode is None:
-            ip4_method = NetworkManager.SETTING_IP4_CONFIG_METHOD_AUTO
+            ip4_method = NM.SETTING_IP4_CONFIG_METHOD_AUTO
         else:
-            ip6_method = NetworkManager.SETTING_IP6_CONFIG_METHOD_AUTO
+            ip6_method = NM.SETTING_IP6_CONFIG_METHOD_AUTO
 
         # If we have a secret, supply it to the new connection right away;
         # adding it afterwards with update_secrets() does not work, and we
         # can't implement a SecretAgent as get_secrets() would need to build a
         # map of a map of gpointers to gpointers which is too much for PyGI
-        partial_conn = NetworkManager.Connection.new()
-        partial_conn.add_setting(NetworkManager.SettingIP4Config(method=ip4_method))
+        partial_conn = NM.SimpleConnection.new()
+        partial_conn.add_setting(NM.SettingIP4Config(method=ip4_method))
         if secret:
-            partial_conn.add_setting(NetworkManager.SettingWirelessSecurity.new())
+            partial_conn.add_setting(NM.SettingWirelessSecurity.new())
             # FIXME: needs update for other auth types
-            partial_conn.update_secrets(NetworkManager.SETTING_WIRELESS_SECURITY_SETTING_NAME,
-                                        {'psk': secret})
+            partial_conn.update_secrets(NM.SETTING_WIRELESS_SECURITY_SETTING_NAME,
+                                        GLib.Variant('a{sv}', {
+                                            'psk': GLib.Variant('s', secret) 
+                                        }))
         if ip6_privacy is not None:
-            partial_conn.add_setting(NetworkManager.SettingIP6Config(ip6_privacy=ip6_privacy,
+            partial_conn.add_setting(NM.SettingIP6Config(ip6_privacy=ip6_privacy,
                                                                      method=ip6_method))
 
         ml = GLib.MainLoop()
         self.cb_conn = None
+        self.cancel = Gio.Cancellable()
+        self.timeout_tag = 0
 
-        def add_activate_cb(client, conn, conn_path, error, data):
-            self.cb_conn = conn
-            self.cb_error = error
+        def add_activate_cb(client, res, data):
+            if (self.timeout_tag > 0):
+                GLib.source_remove(self.timeout_tag)
+                self.timeout_tag = 0
+            try:
+                self.cb_conn = \
+                    self.nmclient.add_and_activate_connection_finish(res)
+            except gi.repository.GLib.Error as e:
+                # Check if the error is "Operation was cancelled"
+                if (e.domain != "g-io-error-quark" or e.code != 19):
+                    self.fail("add_and_activate_connection failed: %s (%s, %d)" %
+                              (e.message, e.domain, e.code))
             ml.quit()
-        self.nmclient.add_and_activate_connection(partial_conn, self.nmdev_w, ap.get_path(), add_activate_cb, None)
+
+        def timeout_cb():
+            self.timeout_tag = -1
+            self.cancel.cancel()
+            ml.quit()
+            return GLib.SOURCE_REMOVE
+
+        self.nmclient.add_and_activate_connection_async(partial_conn, self.nmdev_w, ap.get_path(), self.cancel, add_activate_cb, None)
+        self.timeout_tag = GLib.timeout_add_seconds(300, timeout_cb)
         ml.run()
-        self.assertEqual(self.cb_error, None)
+        if (self.timeout_tag < 0):
+            self.timeout_tag = 0
+            self.fail('Main loop for adding connection timed out!')
+        self.assertNotEqual(self.cb_conn, None)
         active_conn = self.cb_conn
         self.cb_conn = None
 
@@ -288,18 +312,18 @@ class NetworkManagerTest(network_test_base.NetworkTestBase):
         if secret is None:
             self.assertEqual(needed_secrets, (None, []))
         else:
-            self.assertEqual(needed_secrets[0], NetworkManager.SETTING_WIRELESS_SECURITY_SETTING_NAME)
+            self.assertEqual(needed_secrets[0], NM.SETTING_WIRELESS_SECURITY_SETTING_NAME)
             self.assertEqual(type(needed_secrets[1]), list)
             self.assertGreaterEqual(len(needed_secrets[1]), 1)
             # FIXME: needs update for other auth types
-            self.assertIn(needed_secrets[1][0], [NetworkManager.SETTING_WIRELESS_SECURITY_PSK])
+            self.assertIn(needed_secrets[1][0], [NM.SETTING_WIRELESS_SECURITY_PSK])
 
         # we are usually ACTIVATING at this point; wait for completion
         # TODO: 5s is not enough, argh slow DHCP client
-        self.assertEventually(lambda: active_conn.get_state() == NetworkManager.ActiveConnectionState.ACTIVATED,
+        self.assertEventually(lambda: active_conn.get_state() == NM.ActiveConnectionState.ACTIVATED,
                               'timed out waiting for %s to get activated' % active_conn.get_connection(),
                               timeout=600)
-        self.assertEqual(self.nmdev_w.get_state(), NetworkManager.DeviceState.ACTIVATED)
+        self.assertEqual(self.nmdev_w.get_state(), NM.DeviceState.ACTIVATED)
         return (conn, active_conn)
 
     def conn_from_active_conn(self, active_conn):
@@ -310,7 +334,7 @@ class NetworkManagerTest(network_test_base.NetworkTestBase):
         tries = 3
         while tries > 0:
             self.process_glib_events()
-            path = active_conn.get_connection()
+            path = active_conn.get_connection().get_path()
             for dev in active_conn.get_devices():
                 for c in dev.get_available_connections():
                     if c.get_path() == path:
@@ -320,31 +344,6 @@ class NetworkManagerTest(network_test_base.NetworkTestBase):
 
         self.fail('Could not find NMConnection object for %s' % path)
 
-    def check_connected_device_config(self, ipv6_mode, nmdev):
-        '''Check NMDevice configuration state after being connected'''
-
-        time.sleep(10)
-        if ipv6_mode is not None:
-            # FIXME: why do we need to wait here, if state is already ACTIVATED?
-            self.assertEventually(lambda: nmdev.get_ip6_config() is not None, timeout=50)
-            #self.assertEqual(nmdev.get_ip4_config(), None)
-            conf = nmdev.get_ip6_config()
-            self.assertNotEqual(conf, None)
-            # we expect at least a link-local and a RA prefix or DHCP assigned
-            # address
-            addrs = conf.get_addresses()
-            self.assertGreaterEqual(len(addrs), 2, [a.get_address() for a in addrs])
-            # note, we cannot call IP6Address.get_address(), as that returns a
-            # raw gpointer; check address with low-level tools only
-        else:
-            # FIXME: why do we need to wait here, if state is already ACTIVATED?
-            self.assertEventually(lambda: nmdev.get_ip4_config() is not None, timeout=50)
-            conf = nmdev.get_ip4_config()
-            self.assertNotEqual(conf, None)
-            self.assertEqual(len(conf.get_addresses()), 1)
-            self.assertEqual(socket.ntohl(conf.get_addresses()[0].get_address()) & 0xFFFFFF00,
-                             0xC0A80500)  # 192.168.5.x
-
     def check_low_level_config(self, iface, ipv6_mode, ip6_privacy):
         '''Check actual hardware state with ip/iw after being connected'''
 
@@ -358,12 +357,12 @@ class NetworkManagerTest(network_test_base.NetworkTestBase):
                 expected_ip_a.append('inet6 2600::[0-9a-f]+/')
             else:
                 # has address with our prefix and MAC
-                expected_ip_a.append('inet6 2600::[0-9a-f:]+/64 scope global (?:tentative )?(?:mngtmpaddr )?(?:noprefixroute )?dynamic')
+                expected_ip_a.append('inet6 2600::[0-9a-f:]+/64 scope global (?:tentative )?(?:mngtmpaddr )?(?:noprefixroute )?(dynamic|\n\s*valid_lft forever preferred_lft forever)')
                 # has address with our prefix and random IP (Privacy
                 # Extension), if requested
                 priv_re = 'inet6 2600:[0-9a-f:]+/64 scope global temporary (?:tentative )?(?:mngtmpaddr )?dynamic'
-                if ip6_privacy in (NetworkManager.SettingIP6ConfigPrivacy.PREFER_TEMP_ADDR,
-                                   NetworkManager.SettingIP6ConfigPrivacy.PREFER_PUBLIC_ADDR):
+                if ip6_privacy in (NM.SettingIP6ConfigPrivacy.PREFER_TEMP_ADDR,
+                                   NM.SettingIP6ConfigPrivacy.PREFER_PUBLIC_ADDR):
                     expected_ip_a.append(priv_re)
                 else:
                     # FIXME: add a negative test here
@@ -403,10 +402,13 @@ Logs are in '%s'. When done, exit the shell.
         '''no available access point'''
 
         self.start_nm(self.dev_w_client)
+        # Give the interfaces a bit more time to intialized; it may be needed
+        # on ppc64el.
+        time.sleep(30)
         self.assertEventually(self.nmclient.networking_get_enabled, timeout=20)
 
         # state independent properties
-        self.assertEqual(self.nmdev_w.props.device_type, NetworkManager.DeviceType.WIFI)
+        self.assertEqual(self.nmdev_w.props.device_type, NM.DeviceType.WIFI)
         self.assertTrue(self.nmdev_w.props.managed)
         self.assertFalse(self.nmdev_w.props.firmware_missing)
         self.assertTrue(self.nmdev_w.props.udi.startswith('/sys/devices/'), self.nmdev_w.props.udi)
@@ -419,7 +421,7 @@ Logs are in '%s'. When done, exit the shell.
 
         # state dependent properties (disconnected)
         self.assertIn(self.nmdev_w.get_state(),
-                      [NetworkManager.DeviceState.DISCONNECTED, NetworkManager.DeviceState.UNAVAILABLE])
+                      [NM.DeviceState.DISCONNECTED, NM.DeviceState.UNAVAILABLE])
         self.assertEqual(self.nmdev_w.get_access_points(), [])
         self.assertEqual(self.nmdev_w.get_available_connections(), [])
 
@@ -432,25 +434,25 @@ Logs are in '%s'. When done, exit the shell.
         '''Open network, 802.11b, IPv6 with only RA, preferring temp address'''
 
         self.do_test('hw_mode=b\nchannel=1\nssid=' + SSID, 'ra-only', 11000,
-                     ip6_privacy=NetworkManager.SettingIP6ConfigPrivacy.PREFER_TEMP_ADDR)
+                     ip6_privacy=NM.SettingIP6ConfigPrivacy.PREFER_TEMP_ADDR)
 
     def test_open_b_ip6_raonly_pubaddr(self):
         '''Open network, 802.11b, IPv6 with only RA, preferring public address'''
 
         self.do_test('hw_mode=b\nchannel=1\nssid=' + SSID, 'ra-only', 11000,
-                     ip6_privacy=NetworkManager.SettingIP6ConfigPrivacy.PREFER_PUBLIC_ADDR)
+                     ip6_privacy=NM.SettingIP6ConfigPrivacy.PREFER_PUBLIC_ADDR)
 
     def test_open_b_ip6_raonly_no_pe(self):
         '''Open network, 802.11b, IPv6 with only RA, PE disabled'''
 
         self.do_test('hw_mode=b\nchannel=1\nssid=' + SSID, 'ra-only', 11000,
-                     ip6_privacy=NetworkManager.SettingIP6ConfigPrivacy.DISABLED)
+                     ip6_privacy=NM.SettingIP6ConfigPrivacy.DISABLED)
 
     def test_open_b_ip6_dhcp(self):
         '''Open network, 802.11b, IPv6 with DHCP, preferring temp address'''
 
         self.do_test('hw_mode=b\nchannel=1\nssid=' + SSID, '', 11000,
-                     ip6_privacy=NetworkManager.SettingIP6ConfigPrivacy.UNKNOWN)
+                     ip6_privacy=NM.SettingIP6ConfigPrivacy.UNKNOWN)
 
     def test_open_g_ip4(self):
         '''Open network, 802.11g, IPv4'''
@@ -492,7 +494,7 @@ wpa_key_mgmt=WPA-PSK
 wpa_pairwise=CCMP
 wpa_passphrase=12345678
 ''' % SSID, 'ra-only', 54000, '12345678',
-                     ip6_privacy=NetworkManager.SettingIP6ConfigPrivacy.PREFER_TEMP_ADDR)
+                     ip6_privacy=NM.SettingIP6ConfigPrivacy.PREFER_TEMP_ADDR)
 
     @network_test_base.run_in_subprocess
     def test_rfkill(self):
@@ -509,7 +511,7 @@ wpa_passphrase=12345678
         # now block the client interface
         self.set_rfkill(self.dev_w_client, True)
         # disabling should be fast, give it ten seconds
-        self.assertEventually(lambda: self.nmdev_w.get_state() == NetworkManager.DeviceState.UNAVAILABLE,
+        self.assertEventually(lambda: self.nmdev_w.get_state() == NM.DeviceState.UNAVAILABLE,
                               timeout=100)
 
         # dev_w_client should be down now
@@ -518,7 +520,7 @@ wpa_passphrase=12345678
         # turn it back on
         self.set_rfkill(self.dev_w_client, False)
         # this involves DHCP, use same timeout as for regular connection
-        self.assertEventually(lambda: self.nmdev_w.get_state() == NetworkManager.DeviceState.ACTIVATED,
+        self.assertEventually(lambda: self.nmdev_w.get_state() == NM.DeviceState.ACTIVATED,
                               timeout=200)
 
         # dev_w_client should be back up
@@ -543,7 +545,7 @@ wpa_passphrase=12345678
         # on coldplug we expect the AP to be picked out fast
         ap = self.wait_ap(timeout=100)
         self.assertTrue(ap.get_path().startswith('/org/freedesktop/NetworkManager'))
-        self.assertEqual(ap.get_mode(), getattr(NetworkManager, '80211Mode').INFRA)
+        self.assertEqual(ap.get_mode(), getattr(NM, '80211Mode').INFRA)
         self.assertEqual(ap.get_max_bitrate(), expected_max_bitrate)
         #self.assertEqual(ap.get_flags(), )
 
@@ -557,21 +559,19 @@ wpa_passphrase=12345678
         self.assertIn(active_conn.get_uuid(), [c.get_uuid() for c in self.nmclient.get_active_connections()])
         self.assertEqual([d.get_udi() for d in active_conn.get_devices()], [self.nmdev_w.get_udi()])
 
-        self.check_connected_device_config(ipv6_mode, self.nmdev_w)
-
         # check corresponding NMConnection object
         wireless_setting = conn.get_setting_wireless()
-        self.assertEqual(wireless_setting.get_ssid(), SSID.encode())
+        self.assertEqual(wireless_setting.get_ssid().get_data(), SSID.encode())
         self.assertEqual(wireless_setting.get_hidden(), False)
         if secret:
-            self.assertEqual(wireless_setting.get_security(), NetworkManager.SETTING_WIRELESS_SECURITY_SETTING_NAME)
+            self.assertEqual(conn.get_setting_wireless_security().get_name(), NM.SETTING_WIRELESS_SECURITY_SETTING_NAME)
         else:
-            self.assertEqual(wireless_setting.get_security(), None)
+            self.assertEqual(conn.get_setting_wireless_security(), None)
         # for debugging
         #conn.dump()
 
         # for IPv6, check privacy setting
-        if ipv6_mode is not None and ip6_privacy != NetworkManager.SettingIP6ConfigPrivacy.UNKNOWN:
+        if ipv6_mode is not None and ip6_privacy != NM.SettingIP6ConfigPrivacy.UNKNOWN:
             assert ip6_privacy is not None, 'for IPv6 tests you need to specify ip6_privacy flag'
             ip6_setting = conn.get_setting_ip6_config()
             self.assertEqual(ip6_setting.props.ip6_privacy, ip6_privacy)
@@ -608,13 +608,13 @@ Logs are in '%s'. When done, exit the shell.
         '''ethernet: auto-connection, IPv6 with only RA, PE disabled'''
 
         self.do_test('ra-only', auto_connect=True,
-                     ip6_privacy=NetworkManager.SettingIP6ConfigPrivacy.DISABLED)
+                     ip6_privacy=NM.SettingIP6ConfigPrivacy.DISABLED)
 
     def test_auto_ip6_dhcp(self):
         '''ethernet: auto-connection, IPv6 with DHCP'''
 
         self.do_test('', auto_connect=True,
-                     ip6_privacy=NetworkManager.SettingIP6ConfigPrivacy.UNKNOWN)
+                     ip6_privacy=NM.SettingIP6ConfigPrivacy.UNKNOWN)
 
     def test_manual_ip4(self):
         '''ethernet: manual connection, IPv4'''
@@ -625,13 +625,13 @@ Logs are in '%s'. When done, exit the shell.
         '''ethernet: manual connection, IPv6 with only RA, preferring temp address'''
 
         self.do_test('ra-only', auto_connect=False,
-                     ip6_privacy=NetworkManager.SettingIP6ConfigPrivacy.PREFER_TEMP_ADDR)
+                     ip6_privacy=NM.SettingIP6ConfigPrivacy.PREFER_TEMP_ADDR)
 
     def test_manual_ip6_raonly_pubaddr(self):
         '''ethernet: manual connection, IPv6 with only RA, preferring public address'''
 
         self.do_test('ra-only', auto_connect=False,
-                     ip6_privacy=NetworkManager.SettingIP6ConfigPrivacy.PREFER_PUBLIC_ADDR)
+                     ip6_privacy=NM.SettingIP6ConfigPrivacy.PREFER_PUBLIC_ADDR)
 
     #
     # Common test code
@@ -644,45 +644,68 @@ Logs are in '%s'. When done, exit the shell.
         self.setup_eth(ipv6_mode)
         self.start_nm(self.dev_e_client, auto_connect=auto_connect)
 
-        ip4_method = NetworkManager.SETTING_IP4_CONFIG_METHOD_DISABLED
-        ip6_method = NetworkManager.SETTING_IP6_CONFIG_METHOD_IGNORE
+        ip4_method = NM.SETTING_IP4_CONFIG_METHOD_DISABLED
+        ip6_method = NM.SETTING_IP6_CONFIG_METHOD_IGNORE
         if ipv6_mode is None:
-            ip4_method = NetworkManager.SETTING_IP4_CONFIG_METHOD_AUTO
+            ip4_method = NM.SETTING_IP4_CONFIG_METHOD_AUTO
         else:
-            ip6_method = NetworkManager.SETTING_IP6_CONFIG_METHOD_AUTO
+            ip6_method = NM.SETTING_IP6_CONFIG_METHOD_AUTO
 
         if auto_connect:
             # ethernet should auto-connect quickly without an existing defined connection
             self.assertEventually(lambda: len(self.nmclient.get_active_connections()) > 0,
+                                  'timed out waiting for active connections',
                                   timeout=100)
             active_conn = self.nmclient.get_active_connections()[0]
         else:
             # auto-connection was disabled, set up manual connection
-            partial_conn = NetworkManager.Connection.new()
-            partial_conn.add_setting(NetworkManager.SettingIP4Config(method=ip4_method))
+            partial_conn = NM.SimpleConnection.new()
+            partial_conn.add_setting(NM.SettingIP4Config(method=ip4_method))
             if ip6_privacy is not None:
-                partial_conn.add_setting(NetworkManager.SettingIP6Config(ip6_privacy=ip6_privacy,
+                partial_conn.add_setting(NM.SettingIP6Config(ip6_privacy=ip6_privacy,
                                                                          method=ip6_method))
 
             ml = GLib.MainLoop()
             self.cb_conn = None
+            self.cancel = Gio.Cancellable()
+            self.timeout_tag = 0
 
-            def add_activate_cb(client, conn, conn_path, error, data):
-                self.cb_conn = conn
-                self.cb_error = error
+            def add_activate_cb(client, res, data):
+                if (self.timeout_tag > 0):
+                    GLib.source_remove(self.timeout_tag)
+                    self.timeout_tag = 0
+                try:
+                    self.cb_conn = \
+                        self.nmclient.add_and_activate_connection_finish(res)
+                except gi.repository.GLib.Error as e:
+                    # Check if the error is "Operation was cancelled"
+                    if (e.domain != "g-io-error-quark" or e.code != 19):
+                        self.fail("add_and_activate_connection failed: %s (%s, %d)" %
+                                  (e.message, e.domain, e.code))
                 ml.quit()
-            self.nmclient.add_and_activate_connection(partial_conn, self.nmdev_e, None, add_activate_cb, None)
+
+            def timeout_cb():
+                self.timeout_tag = -1
+                self.cancel.cancel()
+                ml.quit()
+                return GLib.SOURCE_REMOVE
+
+            self.nmclient.add_and_activate_connection_async(partial_conn, self.nmdev_e, None, self.cancel, add_activate_cb, None)
+            self.timeout_tag = GLib.timeout_add_seconds(300, timeout_cb)
             ml.run()
-            self.assertEqual(self.cb_error, None)
+            if (self.timeout_tag < 0):
+                self.timeout_tag = 0
+                self.fail('Main loop for adding connection timed out!')
+            self.assertNotEqual(self.cb_conn, None)
             active_conn = self.cb_conn
             self.cb_conn = None
 
         # we are usually ACTIVATING at this point; wait for completion
         # TODO: 5s is not enough, argh slow DHCP client
-        self.assertEventually(lambda: active_conn.get_state() == NetworkManager.ActiveConnectionState.ACTIVATED,
+        self.assertEventually(lambda: active_conn.get_state() == NM.ActiveConnectionState.ACTIVATED,
                               'timed out waiting for %s to get activated' % active_conn.get_connection(),
                               timeout=150)
-        self.assertEqual(self.nmdev_e.get_state(), NetworkManager.DeviceState.ACTIVATED)
+        self.assertEqual(self.nmdev_e.get_state(), NM.DeviceState.ACTIVATED)
 
         conn = self.conn_from_active_conn(active_conn)
         self.assertTrue(conn.verify())
@@ -691,13 +714,11 @@ Logs are in '%s'. When done, exit the shell.
         self.assertIn(active_conn.get_uuid(), [c.get_uuid() for c in self.nmclient.get_active_connections()])
         self.assertEqual([d.get_udi() for d in active_conn.get_devices()], [self.nmdev_e.get_udi()])
 
-        self.check_connected_device_config(ipv6_mode, self.nmdev_e)
-
         # for IPv6, check privacy setting
         if ipv6_mode is not None:
             assert ip6_privacy is not None, 'for IPv6 tests you need to specify ip6_privacy flag'
-            if ip6_privacy not in (NetworkManager.SettingIP6ConfigPrivacy.UNKNOWN,
-                                   NetworkManager.SettingIP6ConfigPrivacy.DISABLED):
+            if ip6_privacy not in (NM.SettingIP6ConfigPrivacy.UNKNOWN,
+                                   NM.SettingIP6ConfigPrivacy.DISABLED):
                 ip6_setting = conn.get_setting_ip6_config()
                 self.assertEqual(ip6_setting.props.ip6_privacy, ip6_privacy)
 
@@ -730,10 +751,10 @@ class Hotplug(NetworkManagerTest):
                               timeout=300)
         active_conn = self.nmclient.get_active_connections()[0]
 
-        self.assertEventually(lambda: active_conn.get_state() == NetworkManager.ActiveConnectionState.ACTIVATED,
+        self.assertEventually(lambda: active_conn.get_state() == NM.ActiveConnectionState.ACTIVATED,
                               'timed out waiting for %s to get activated' % active_conn.get_connection(),
                               timeout=80)
-        self.assertEqual(self.nmdev_e.get_state(), NetworkManager.DeviceState.ACTIVATED)
+        self.assertEqual(self.nmdev_e.get_state(), NM.DeviceState.ACTIVATED)
 
         conn = self.conn_from_active_conn(active_conn)
         self.assertTrue(conn.verify())
@@ -806,7 +827,7 @@ class Suspend(NetworkManagerTest, DBusTestCase):
         self.obj_logind.EmitSignal('', 'PrepareForSleep', 'b', [True])
 
         # disabling should be fast, give it one second
-        self.assertEventually(lambda: self.nmdev_w.get_state() == NetworkManager.DeviceState.UNMANAGED,
+        self.assertEventually(lambda: self.nmdev_w.get_state() == NM.DeviceState.UNMANAGED,
                               timeout=10)
         self.assert_iface_down(self.dev_w_client)
 
@@ -814,7 +835,7 @@ class Suspend(NetworkManagerTest, DBusTestCase):
         self.obj_logind.EmitSignal('', 'PrepareForSleep', 'b', [False])
 
         # this involves DHCP, use same timeout as for regular connection
-        self.assertEventually(lambda: self.nmdev_w.get_state() == NetworkManager.DeviceState.ACTIVATED,
+        self.assertEventually(lambda: self.nmdev_w.get_state() == NM.DeviceState.ACTIVATED,
                               timeout=100)
 
         # dev_w_client should be back up
